@@ -33,25 +33,35 @@
 
 #include "gpm-common.h"
 #include "gpm-debug.h"
-#include "gpm-common.h"
 
 static gboolean is_init = FALSE;	/* if we are initialised */
 static gboolean do_verbose = FALSE;	/* if we should print out debugging */
+static GSList *list = NULL;
+
+/**
+ * gpm_add_debug_option:
+ **/
+void
+gpm_add_debug_option (const gchar *option)
+{
+	/* adding debug option to list */
+	list = g_slist_prepend (list, (gpointer) option);
+}
 
 /**
  * gpm_print_line:
  **/
 static void
-gpm_print_line (const char *func,
-		const char *file,
-		const int   line,
-		const char *buffer)
+gpm_print_line (const gchar *func,
+		const gchar *file,
+		const int    line,
+		const gchar *buffer)
 {
-	char   *str_time;
+	gchar   *str_time;
 	time_t  the_time;
 
 	time (&the_time);
-	str_time = g_new0 (char, 255);
+	str_time = g_new0 (gchar, 255);
 	strftime (str_time, 254, "%H:%M:%S", localtime (&the_time));
 
 	fprintf (stderr, "[%s] %s:%d (%s):\t %s\n",
@@ -59,19 +69,58 @@ gpm_print_line (const char *func,
 	g_free (str_time);
 }
 
+/**
+ * gpm_debug_strcmp_func
+ * @a: Pointer to the data to test
+ * @b: Pointer to a cookie to compare
+ * Return value: 0 if cookie matches
+ **/
+static gint
+gpm_debug_strcmp_func (gconstpointer a, gconstpointer b)
+{
+	gchar *aa = (gchar *) a;
+	gchar *bb = (gchar *) b;
+	return strcmp (aa, bb);
+}
+
+/**
+ * gpm_debug_in_options:
+ **/
+static gboolean
+gpm_debug_in_options (const gchar *file)
+{
+	GSList *node;
+	gchar *name;
+	guint8 len;
+
+	/* get rid of the "gpm-" prefix */
+	name = strdup (&file[4]);
+
+	/* get rid of .c */
+	len = strlen (name);
+	if (len>2) {
+		name[len-2] = '\0';
+	}
+
+	/* find string in list */
+	node = g_slist_find_custom (list, name, gpm_debug_strcmp_func);
+	g_free (name);
+	return (node != NULL);
+}
+
 /**
  * gpm_debug_real:
  **/
 void
-gpm_debug_real (const char *func,
-		const char *file,
-		const int   line,
-		const char *format, ...)
+gpm_debug_real (const gchar *func,
+		const gchar *file,
+		const int    line,
+		const gchar *format, ...)
 {
 	va_list args;
-	char    buffer [1025];
+	gchar    buffer [1025];
 
-	if (! do_verbose) {
+	if (do_verbose == FALSE && gpm_debug_in_options (file) == FALSE) {
 		return;
 	}
 
@@ -86,15 +135,15 @@ gpm_debug_real (const char *func,
  * gpm_warning_real:
  **/
 void
-gpm_warning_real (const char *func,
-		  const char *file,
-		  const int   line,
-		  const char *format, ...)
+gpm_warning_real (const gchar *func,
+		  const gchar *file,
+		  const int    line,
+		  const gchar *format, ...)
 {
 	va_list args;
-	char    buffer [1025];
+	gchar buffer[1025];
 
-	if (! do_verbose) {
+	if (do_verbose == FALSE) {
 		return;
 	}
 
@@ -128,10 +177,10 @@ gpm_bugzilla (void)
  * Logs some text to the syslog, usually in /var/log/messages
  **/
 void
-gpm_syslog (const char *format, ...)
+gpm_syslog (const gchar *format, ...)
 {
 	va_list args;
-	char    buffer [1025];
+	gchar buffer[1025];
 
 	va_start (args, format);
 	g_vsnprintf (buffer, 1024, format, args);
@@ -170,10 +219,10 @@ gpm_debug_init (gboolean debug)
  * that is the least of our problems...
  **/
 void
-gpm_critical_error (const char *format, ...)
+gpm_critical_error (const gchar *format, ...)
 {
 	va_list args;
-	char    buffer [1025];
+	gchar buffer[1025];
 	GtkWidget *dialog;
 
 	va_start (args, format);
@@ -203,8 +252,9 @@ gpm_critical_error (const char *format, ...)
 void
 gpm_debug_shutdown (void)
 {
-	if (! is_init)
+	if (! is_init) {
 		return;
+	}
 
 	gpm_debug ("Shutting down debugging");
 	is_init = FALSE;
