@@ -43,7 +43,6 @@ static void     gpm_hal_cpufreq_finalize   (GObject	*object);
 
 struct GpmHalCpuFreqPrivate
 {
-	gboolean		 has_hardware;
 	GpmProxy		*gproxy;
 	GpmHal			*hal;
 	guint			 available_governors;
@@ -107,40 +106,6 @@ gpm_hal_cpufreq_enum_to_string (GpmHalCpuFreqEnum cpufreq_type)
 	return governor;
 }
 
-/**
- * gpm_hal_cpufreq_handle_error:
- * @ret: return value (==0 in this case)
- * @method: The method name
- * Return value: If the method succeeded
- **/
-static gboolean
-gpm_hal_cpufreq_handle_error (GError *error, const gchar *method)
-{
-	gboolean retval = TRUE;
-
-	g_return_val_if_fail (method != NULL, FALSE);
-
-	if (error) {
-		gpm_debug ("%s failed\n(%s)", method, error->message);
-		retval = FALSE;
-		g_error_free (error);
-	}
-	return retval;
-}
-
-/**
- * gpm_hal_cpufreq_has_hardware:
- *
- * @cpufreq: This cpufreq class instance
- * Return value: If we have cpufreq support in hal
- **/
-gboolean
-gpm_hal_cpufreq_has_hardware (GpmHalCpuFreq *cpufreq)
-{
-	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
-	return cpufreq->priv->has_hardware;
-}
-
 /**
  * gpm_hal_cpufreq_set_performance:
  *
@@ -152,19 +117,15 @@ gboolean
 gpm_hal_cpufreq_set_performance (GpmHalCpuFreq *cpufreq, guint performance)
 {
 	GError *error = NULL;
-	gboolean retval;
+	gboolean ret;
 	GpmHalCpuFreqEnum cpufreq_type;
 	DBusGProxy *proxy;
 
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 	g_return_val_if_fail (performance >= 0, FALSE);
 	g_return_val_if_fail (performance <= 100, FALSE);
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		return FALSE;
-	}
-
 	gpm_debug ("Doing SetCPUFreqPerformance (%i)", performance);
 
 	/* we need to find the current governor to see if it's sane */
@@ -180,15 +141,24 @@ gpm_hal_cpufreq_set_performance (GpmHalCpuFreq *cpufreq, guint performance)
 
 	proxy = gpm_proxy_get_proxy (cpufreq->priv->gproxy);
 	if (proxy == NULL) {
-		g_warning ("not connected");
+		gpm_warning ("not connected");
 		return FALSE;
 	}	
 
-	dbus_g_proxy_call (proxy, "SetCPUFreqPerformance", &error,
-			   G_TYPE_INT, performance, G_TYPE_INVALID,
-			   G_TYPE_INVALID);
-	retval = gpm_hal_cpufreq_handle_error (error, "SetCPUFreqPerformance");
-	return retval;
+	ret = dbus_g_proxy_call (proxy, "SetCPUFreqPerformance", &error,
+				 G_TYPE_INT, performance,
+				 G_TYPE_INVALID,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("SetCPUFreqPerformance failed!");
+		return FALSE;
+	}
+	return TRUE;
 }
 
 /**
@@ -203,38 +173,41 @@ gpm_hal_cpufreq_set_governor (GpmHalCpuFreq    *cpufreq,
 			      GpmHalCpuFreqEnum cpufreq_type)
 {
 	GError *error = NULL;
-	gboolean retval;
+	gboolean ret;
 	const gchar *governor;
 	DBusGProxy *proxy;
 
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 	g_return_val_if_fail (cpufreq_type != GPM_CPUFREQ_UNKNOWN, FALSE);
+
 	governor = gpm_hal_cpufreq_enum_to_string (cpufreq_type);
 	g_return_val_if_fail (governor != NULL, FALSE);
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		return FALSE;
-	}
-
 	proxy = gpm_proxy_get_proxy (cpufreq->priv->gproxy);
 	if (proxy == NULL) {
-		g_warning ("not connected");
+		gpm_warning ("not connected");
 		return FALSE;
 	}	
 
 	gpm_debug ("Doing SetCPUFreqGovernor (%s)", governor);
-	dbus_g_proxy_call (proxy, "SetCPUFreqGovernor", &error,
-			   G_TYPE_STRING, governor, G_TYPE_INVALID,
-			   G_TYPE_INVALID);
-	retval = gpm_hal_cpufreq_handle_error (error, "SetCPUFreqGovernor");
-
-	/* save the cache */
-	if (retval == TRUE) {
-		cpufreq->priv->current_governor = cpufreq_type;
+	ret = dbus_g_proxy_call (proxy, "SetCPUFreqGovernor", &error,
+				 G_TYPE_STRING, governor,
+				 G_TYPE_INVALID,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("SetCPUFreqGovernor failed!");
+		return FALSE;
 	}
 
-	return retval;
+	/* save the cache */
+	cpufreq->priv->current_governor = cpufreq_type;
+	return TRUE;
 }
 
 /**
@@ -249,44 +222,54 @@ gpm_hal_cpufreq_get_governors (GpmHalCpuFreq     *cpufreq,
 			       GpmHalCpuFreqEnum *cpufreq_type)
 {
 	GError *error = NULL;
-	gboolean retval;
+	gboolean ret;
 	char **strlist;
 	int i = 0;
 	DBusGProxy *proxy;
+	GpmHalCpuFreqEnum types = GPM_CPUFREQ_UNKNOWN;
 
-	*cpufreq_type = GPM_CPUFREQ_UNKNOWN;
-
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 	g_return_val_if_fail (cpufreq_type != NULL, FALSE);
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		return FALSE;
-	}
-
 	proxy = gpm_proxy_get_proxy (cpufreq->priv->gproxy);
 	if (proxy == NULL) {
-		g_warning ("not connected");
+		gpm_warning ("not connected");
+		*cpufreq_type = GPM_CPUFREQ_UNKNOWN;
 		return FALSE;
 	}	
 
 	gpm_debug ("Doing GetCPUFreqAvailableGovernors");
-	dbus_g_proxy_call (proxy, "GetCPUFreqAvailableGovernors", &error,
-			   G_TYPE_INVALID,
-			   G_TYPE_STRV, &strlist,
-			   G_TYPE_INVALID);
-	retval = gpm_hal_cpufreq_handle_error (error, "GetCPUFreqAvailableGovernors");
+	ret = dbus_g_proxy_call (proxy, "GetCPUFreqAvailableGovernors", &error,
+				 G_TYPE_INVALID,
+				 G_TYPE_STRV, &strlist,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("GetCPUFreqAvailableGovernors failed!");
+		*cpufreq_type = GPM_CPUFREQ_UNKNOWN;
+		return FALSE;
+	}
 
 	/* treat as binary flags */
-	if (retval) {
-		while (strlist && strlist[i]) {
-			*cpufreq_type += gpm_hal_cpufreq_string_to_enum (strlist[i]);
-			++i;
-		}
+	while (strlist && strlist[i]) {
+		types += gpm_hal_cpufreq_string_to_enum (strlist[i]);
+		++i;
 	}
-	cpufreq->priv->available_governors = i;
 
-	return retval;
+	/* when we have conservative and ondemand available, only expose
+	   conservative in the UI. They are too similar. */
+	if (types & GPM_CPUFREQ_ONDEMAND && types & GPM_CPUFREQ_CONSERVATIVE) {
+		types -= GPM_CPUFREQ_ONDEMAND;
+	}
+
+	*cpufreq_type = types;
+	cpufreq->priv->available_governors = i;
+	return TRUE;
 }
 
 /**
@@ -302,13 +285,9 @@ gpm_hal_cpufreq_get_number_governors (GpmHalCpuFreq *cpufreq,
 {
 	GpmHalCpuFreqEnum cpufreq_type;
 
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		return 0;
-	}
-
 	if (use_cache == FALSE || cpufreq->priv->available_governors == -1) {
 		gpm_hal_cpufreq_get_governors (cpufreq, &cpufreq_type);
 	}
@@ -327,19 +306,14 @@ gpm_hal_cpufreq_get_consider_nice (GpmHalCpuFreq *cpufreq,
 				   gboolean      *consider_nice)
 {
 	GError *error = NULL;
-	gboolean retval;
+	gboolean ret;
 	GpmHalCpuFreqEnum cpufreq_type;
 	DBusGProxy *proxy;
 
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 	g_return_val_if_fail (consider_nice != NULL, FALSE);
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		*consider_nice = FALSE;
-		return FALSE;
-	}
-
 	/* we need to find the current governor to see if it's sane */
 	if (cpufreq->priv->current_governor == GPM_CPUFREQ_UNKNOWN) {
 		gpm_hal_cpufreq_get_governor (cpufreq, &cpufreq_type);
@@ -355,17 +329,25 @@ gpm_hal_cpufreq_get_consider_nice (GpmHalCpuFreq *cpufreq,
 
 	proxy = gpm_proxy_get_proxy (cpufreq->priv->gproxy);
 	if (proxy == NULL) {
-		g_warning ("not connected");
+		gpm_warning ("not connected");
 		return FALSE;
 	}	
 
 	gpm_debug ("Doing GetCPUFreqConsiderNice");
-	dbus_g_proxy_call (proxy, "GetCPUFreqConsiderNice", &error,
-			   G_TYPE_INVALID,
-			   G_TYPE_BOOLEAN, consider_nice,
-			   G_TYPE_INVALID);
-	retval = gpm_hal_cpufreq_handle_error (error, "GetCPUFreqConsiderNice");
-	return retval;
+	ret = dbus_g_proxy_call (proxy, "GetCPUFreqConsiderNice", &error,
+				 G_TYPE_INVALID,
+				 G_TYPE_BOOLEAN, consider_nice,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("GetCPUFreqConsiderNice failed!");
+		return FALSE;
+	}
+	return TRUE;
 }
 
 /**
@@ -380,19 +362,14 @@ gpm_hal_cpufreq_get_performance (GpmHalCpuFreq *cpufreq,
 				 guint         *performance)
 {
 	GError *error = NULL;
-	gboolean retval;
+	gboolean ret;
 	GpmHalCpuFreqEnum cpufreq_type;
 	DBusGProxy *proxy;
 
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 	g_return_val_if_fail (performance != NULL, FALSE);
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		*performance = -1;
-		return FALSE;
-	}
-
 	/* we need to find the current governor to see if it's sane */
 	if (cpufreq->priv->current_governor == GPM_CPUFREQ_UNKNOWN) {
 		gpm_hal_cpufreq_get_governor (cpufreq, &cpufreq_type);
@@ -407,17 +384,25 @@ gpm_hal_cpufreq_get_performance (GpmHalCpuFreq *cpufreq,
 
 	proxy = gpm_proxy_get_proxy (cpufreq->priv->gproxy);
 	if (proxy == NULL) {
-		g_warning ("not connected");
+		gpm_warning ("not connected");
 		return FALSE;
 	}	
 
 	gpm_debug ("Doing GetCPUFreqPerformance");
-	dbus_g_proxy_call (proxy, "GetCPUFreqPerformance", &error,
-			   G_TYPE_INVALID,
-			   G_TYPE_INT, performance,
-			   G_TYPE_INVALID);
-	retval = gpm_hal_cpufreq_handle_error (error, "GetCPUFreqPerformance");
-	return retval;
+	ret = dbus_g_proxy_call (proxy, "GetCPUFreqPerformance", &error,
+				 G_TYPE_INVALID,
+				 G_TYPE_INT, performance,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("GetCPUFreqPerformance failed!");
+		return FALSE;
+	}
+	return TRUE;
 }
 
 /**
@@ -432,20 +417,16 @@ gpm_hal_cpufreq_get_governor (GpmHalCpuFreq     *cpufreq,
 			      GpmHalCpuFreqEnum *cpufreq_type)
 {
 	GError *error = NULL;
-	gboolean retval;
+	gboolean ret;
 	gchar *governor;
 	DBusGProxy *proxy;
 
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 	g_return_val_if_fail (cpufreq_type, FALSE);
 
 	*cpufreq_type = GPM_CPUFREQ_UNKNOWN;
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		return FALSE;
-	}
-
 	/* use the cache */
 	if (cpufreq->priv->current_governor != GPM_CPUFREQ_UNKNOWN) {
 		return cpufreq->priv->current_governor;
@@ -453,24 +434,33 @@ gpm_hal_cpufreq_get_governor (GpmHalCpuFreq     *cpufreq,
 
 	proxy = gpm_proxy_get_proxy (cpufreq->priv->gproxy);
 	if (proxy == NULL) {
-		g_warning ("not connected");
+		gpm_warning ("not connected");
 		return FALSE;
 	}	
 
 	gpm_debug ("Doing GetCPUFreqGovernor");
-	dbus_g_proxy_call (proxy, "GetCPUFreqGovernor", &error,
-			   G_TYPE_INVALID,
-			   G_TYPE_STRING, &governor,
-			   G_TYPE_INVALID);
-	retval = gpm_hal_cpufreq_handle_error (error, "GetCPUFreqGovernor");
-
-	/* convert to enumerated type */
-	if (retval == TRUE && governor != NULL) {
-		*cpufreq_type = gpm_hal_cpufreq_string_to_enum (governor);
-		cpufreq->priv->current_governor = *cpufreq_type;
+	ret = dbus_g_proxy_call (proxy, "GetCPUFreqGovernor", &error,
+				 G_TYPE_INVALID,
+				 G_TYPE_STRING, &governor,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("GetCPUFreqGovernor failed!");
+		return FALSE;
 	}
 
-	return retval;
+	/* convert to enumerated type */
+	if (governor != NULL) {
+		*cpufreq_type = gpm_hal_cpufreq_string_to_enum (governor);
+		cpufreq->priv->current_governor = *cpufreq_type;
+		g_free (governor);
+	}
+
+	return TRUE;
 }
 
 /**
@@ -485,17 +475,13 @@ gpm_hal_cpufreq_set_consider_nice (GpmHalCpuFreq *cpufreq,
 				   gboolean       consider_nice)
 {
 	GError *error = NULL;
-	gboolean retval;
+	gboolean ret;
 	GpmHalCpuFreqEnum cpufreq_type;
 	DBusGProxy *proxy;
 
+	g_return_val_if_fail (cpufreq != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_HAL_CPUFREQ (cpufreq), FALSE);
 
-	/* do we support speedstep and have a new enough hal? */
-	if (! cpufreq->priv->has_hardware) {
-		return FALSE;
-	}
-
 	/* we need to find the current governor to see if it's sane */
 	if (cpufreq->priv->current_governor == GPM_CPUFREQ_UNKNOWN) {
 		gpm_hal_cpufreq_get_governor (cpufreq, &cpufreq_type);
@@ -510,16 +496,25 @@ gpm_hal_cpufreq_set_consider_nice (GpmHalCpuFreq *cpufreq,
 
 	proxy = gpm_proxy_get_proxy (cpufreq->priv->gproxy);
 	if (proxy == NULL) {
-		g_warning ("not connected");
+		gpm_warning ("not connected");
 		return FALSE;
 	}	
 
 	gpm_debug ("Doing SetCPUFreqConsiderNice (%i)", consider_nice);
-	dbus_g_proxy_call (proxy, "SetCPUFreqConsiderNice", &error,
-			   G_TYPE_BOOLEAN, consider_nice, G_TYPE_INVALID,
-			   G_TYPE_INVALID);
-	retval = gpm_hal_cpufreq_handle_error (error, "SetCPUFreqConsiderNice");
-	return retval;
+	ret = dbus_g_proxy_call (proxy, "SetCPUFreqConsiderNice", &error,
+				 G_TYPE_BOOLEAN, consider_nice,
+				 G_TYPE_INVALID,
+				 G_TYPE_INVALID);
+	if (error) {
+		gpm_debug ("ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		gpm_warning ("SetCPUFreqConsiderNice failed!");
+		return FALSE;
+	}
+	return TRUE;
 }
 
 /**
@@ -542,8 +537,6 @@ gpm_hal_cpufreq_class_init (GpmHalCpuFreqClass *klass)
 static void
 gpm_hal_cpufreq_init (GpmHalCpuFreq *cpufreq)
 {
-	int num_caps;
-
 	cpufreq->priv = GPM_GPM_CPUFREQ_GET_PRIVATE (cpufreq);
 
 	cpufreq->priv->hal = gpm_hal_new ();
@@ -558,15 +551,6 @@ gpm_hal_cpufreq_init (GpmHalCpuFreq *cpufreq)
 	/* set defaults */
 	cpufreq->priv->available_governors = -1;
 	cpufreq->priv->current_governor = GPM_CPUFREQ_UNKNOWN;
-	cpufreq->priv->has_hardware = FALSE;
-
-	num_caps = gpm_hal_num_devices_of_capability (cpufreq->priv->hal,
-						      "cpufreq_control");
-
-	/* if we have cpufreq_control then we can use hal for cpufreq control */
-	if (num_caps > 0) {
-		cpufreq->priv->has_hardware = TRUE;
-	}
 }
 
 /**
@@ -583,12 +567,43 @@ gpm_hal_cpufreq_finalize (GObject *object)
 	cpufreq = GPM_HAL_CPUFREQ (object);
 	cpufreq->priv = GPM_GPM_CPUFREQ_GET_PRIVATE (cpufreq);
 
-	g_object_unref (cpufreq->priv->hal);
-	g_object_unref (cpufreq->priv->gproxy);
+	if (cpufreq->priv->hal != NULL) {
+		g_object_unref (cpufreq->priv->hal);
+	}
+	if (cpufreq->priv->gproxy != NULL) {
+		g_object_unref (cpufreq->priv->gproxy);
+	}
 
 	G_OBJECT_CLASS (gpm_hal_cpufreq_parent_class)->finalize (object);
 }
 
+/**
+ * gpm_hal_cpufreq_has_hw:
+ *
+ * Self contained function that works out if we have the hardware.
+ * If not, we return FALSE and the module is unloaded.
+ **/
+static gboolean
+gpm_hal_cpufreq_has_hw (void)
+{
+	GpmHal *hal;
+	gchar **names;
+	gboolean ret = TRUE;
+
+	/* okay, as singleton - so we don't allocate more memory */
+	hal = gpm_hal_new ();
+	gpm_hal_device_find_capability (hal, "cpufreq_control", &names);
+
+	/* nothing found */
+	if (names == NULL || names[0] == NULL) {
+		ret = FALSE;
+	}
+
+	gpm_hal_free_capability (hal, names);
+	g_object_unref (hal);
+	return ret;
+}
+
 /**
  * gpm_hal_cpufreq_new:
  * Return value: new GpmHalCpuFreq instance.
@@ -596,6 +611,11 @@ gpm_hal_cpufreq_finalize (GObject *object)
 GpmHalCpuFreq *
 gpm_hal_cpufreq_new (void)
 {
+	/* only load an instance of this module if we have the hardware */
+	if (gpm_hal_cpufreq_has_hw () == FALSE) {
+		return NULL;
+	}
+
 	if (gpm_hal_cpufreq_object) {
 		g_object_ref (gpm_hal_cpufreq_object);
 	} else {
