@@ -26,14 +26,16 @@
 
 G_BEGIN_DECLS
 
-#define	HAL_DBUS_SERVICE		"org.freedesktop.Hal"
-#define	HAL_DBUS_PATH_MANAGER		"/org/freedesktop/Hal/Manager"
-#define	HAL_DBUS_INTERFACE_MANAGER	"org.freedesktop.Hal.Manager"
-#define	HAL_DBUS_INTERFACE_DEVICE	"org.freedesktop.Hal.Device"
-#define	HAL_DBUS_INTERFACE_LAPTOP_PANEL	"org.freedesktop.Hal.Device.LaptopPanel"
-#define	HAL_DBUS_INTERFACE_POWER	"org.freedesktop.Hal.Device.SystemPowerManagement"
-#define	HAL_DBUS_INTERFACE_CPUFREQ	"org.freedesktop.Hal.Device.CPUFreq"
-#define HAL_ROOT_COMPUTER		"/org/freedesktop/Hal/devices/computer"
+#define	HAL_DBUS_SERVICE		 "org.freedesktop.Hal"
+#define	HAL_DBUS_PATH_MANAGER		 "/org/freedesktop/Hal/Manager"
+#define	HAL_DBUS_INTERFACE_MANAGER	 "org.freedesktop.Hal.Manager"
+#define	HAL_DBUS_INTERFACE_DEVICE	 "org.freedesktop.Hal.Device"
+#define	HAL_DBUS_INTERFACE_LAPTOP_PANEL	 "org.freedesktop.Hal.Device.LaptopPanel"
+#define	HAL_DBUS_INTERFACE_POWER	 "org.freedesktop.Hal.Device.SystemPowerManagement"
+#define	HAL_DBUS_INTERFACE_CPUFREQ	 "org.freedesktop.Hal.Device.CPUFreq"
+#define	HAL_DBUS_INTERFACE_KBD_BACKLIGHT "org.freedesktop.Hal.Device.KeyboardBacklight"
+#define	HAL_DBUS_INTERFACE_LIGHT_SENSOR	 "org.freedesktop.Hal.Device.LightSensor"
+#define HAL_ROOT_COMPUTER		 "/org/freedesktop/Hal/devices/computer"
 
 #define GPM_TYPE_HAL		(gpm_hal_get_type ())
 #define GPM_HAL(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GPM_TYPE_HAL, GpmHal))
@@ -106,11 +108,19 @@ gboolean	 gpm_hal_device_get_int			(GpmHal		*hal,
 							 const gchar	*udi,
 							 const gchar	*key,
 							 gint		*value);
+gboolean	 gpm_hal_device_get_uint		(GpmHal		*hal,
+							 const gchar	*udi,
+							 const gchar	*key,
+							 guint		*value);
 gboolean	 gpm_hal_device_find_capability		(GpmHal		*hal,
 							 const gchar	*capability,
 							 gchar	      ***value);
 gboolean	 gpm_hal_device_rescan_capability	(GpmHal		*hal,
 							 const char	*capability);
+gboolean	 gpm_hal_device_has_capability		(GpmHal		*hal,
+							 const gchar	*udi,
+							 const gchar	*capability,
+							 gboolean	*has_capability);
 gint		 gpm_hal_num_devices_of_capability	(GpmHal		*hal,
 							 const gchar	*capability);
 gint		 gpm_hal_num_devices_of_capability_with_value (GpmHal	*hal,
@@ -120,9 +130,11 @@ gint		 gpm_hal_num_devices_of_capability_with_value (GpmHal	*hal,
 void		 gpm_hal_free_capability		(GpmHal		*hal,
 							 gchar		**value);
 gboolean	 gpm_hal_device_watch_condition		(GpmHal		*hal,
-							 const char	*udi);
+							 const char	*udi,
+							 gboolean	 force);
 gboolean	 gpm_hal_device_watch_propery_modified	(GpmHal		*hal,
-							 const char	*udi);
+							 const char	*udi,
+							 gboolean	 force);
 gboolean	 gpm_hal_device_remove_condition	(GpmHal		*hal,
 							 const char	*udi);
 gboolean	 gpm_hal_device_remove_propery_modified	(GpmHal		*hal,
