@@ -45,13 +45,11 @@ typedef struct
 {
 	GObjectClass	parent_class;
 	void		(* gs_delay_changed)		(GpmScreensaver	*screensaver,
-					    		 int		 delay);
+					    		 gint		 delay);
 	void		(* connection_changed)		(GpmScreensaver	*screensaver,
 					    		 gboolean	 connected);
 	void		(* auth_request)		(GpmScreensaver	*screensaver,
 					    		 gboolean	 auth);
-	void		(* daemon_start)		(GpmScreensaver	*screensaver);
-	void		(* daemon_stop)			(GpmScreensaver	*screensaver);
 } GpmScreensaverClass;
 
 GType		 gpm_screensaver_get_type		(void);
@@ -64,7 +62,7 @@ gboolean	 gpm_screensaver_lock_set		(GpmScreensaver	*screensaver,
 							 gboolean	 lock);
 gboolean	 gpm_screensaver_lock_enabled		(GpmScreensaver	*screensaver);
 guint32 	 gpm_screensaver_add_throttle    	(GpmScreensaver	*screensaver,
-							 const char	*reason);
+							 const gchar	*reason);
 gboolean 	 gpm_screensaver_remove_throttle    	(GpmScreensaver	*screensaver,
 							 guint32         cookie);
 gboolean	 gpm_screensaver_check_running		(GpmScreensaver	*screensaver);
