@@ -29,11 +29,11 @@ G_BEGIN_DECLS
 #define GPM_STOCK_APP_ICON			"gpm-primary-charged"
 #define GPM_STOCK_AC_ADAPTER			"gpm-ac-adapter"
 #define GPM_STOCK_BATTERY_CHARGED		"gpm-primary-charged"
-#define GPM_STOCK_BATTERY_BROKEN		"gpm-primary-broken"
-#define GPM_STOCK_UPS_BROKEN			"gpm-ups-broken"
-#define GPM_STOCK_SUSPEND_TO_DISK		"gpm-suspend-to-disk"
-#define GPM_STOCK_SUSPEND_TO_RAM		"gpm-suspend-to-ram"
-#define GPM_STOCK_BRIGHTNESS			"gpm-brightness"
+#define GPM_STOCK_HIBERNATE			"gpm-hibernate"
+#define GPM_STOCK_SUSPEND			"gpm-suspend"
+#define GPM_STOCK_STATISTICS			"gpm-statistics"
+#define GPM_STOCK_BRIGHTNESS_LCD		"gpm-brightness-lcd"
+#define GPM_STOCK_BRIGHTNESS_KBD		"gpm-brightness-kbd"
 
 gboolean	gpm_stock_icons_init			(void);
 void		gpm_stock_icons_shutdown		(void);
